@@ -237,6 +237,8 @@ def xact():
     if 'date' in query:
         date_param = query['date']
         params += date_param + ' '
+    if 'payee' in query:
+        params += f'@{query["payee"]} '
     if 'freeText' in query:
         free_text = query['freeText']
         params += free_text
